<?php
/**
 * Front Page Boxes Class
 *
 * @since 2.0
 */

// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Lana_Front_Page_Boxes {
    
    /**
     * Class Constructor
     *
     * @since 2.0
     */
    function __construct() {
        
        self::render();
        
    }
    
    /**
     * Render Front Page Boxes
     *
     * @since 2.0
     */
    public static function render() {
        
        // Box 1
        $box[1]['enable']   = esc_attr( get_theme_mod( 'lana_front_page_box_1_enable', true ) );
        $box[1]['icon']     = esc_attr( get_theme_mod( 'lana_front_page_box_1_icon', 'tablet' ) );
        $box[1]['title']    = esc_html( get_theme_mod( 'lana_front_page_box_1_title', __( 'Responsive Layout', 'lana' ) ) );
        $box[1]['text']     = esc_html( get_theme_mod( 'lana_front_page_box_1_text', __( 'Powerful Layout with Responsive functionality that can be adapted to any screen size.', 'lana' ) ) );
        
        // Box 2
        $box[2]['enable']   = esc_attr( get_theme_mod( 'lana_front_page_box_2_enable', true ) );
        $box[2]['icon']     = esc_attr( get_theme_mod( 'lana_front_page_box_2_icon', 'magic' ) );
        $box[2]['title']    = esc_html( get_theme_mod( 'lana_front_page_box_2_title', __( 'Powerful Performance', 'lana' ) ) );
        $box[2]['text']     = esc_html( get_theme_mod( 'lana_front_page_box_2_text', __( 'Optimized code that are completely customizable and deliver unmatched fast performance.', 'lana' ) ) ); 
        
        // Check if boxed are disabled or enabled.
        if( ! $box[1]['enable'] && ! $box[2]['enable'] ) {
            $enabled = false;
        } else {
            $enabled = true;
        } ?>
        
        <?php // Enable front page boxes only on home page or front page. 
        if( $enabled && is_home() && is_front_page() || $enabled && is_front_page() ): ?>
        <section>
            
            <div class="features">
                
            <?php if( $box[1]['enable'] ): ?>
            <!-- Front Page Box #1 -->
            <article>

                <?php if( $box[1]['icon'] ): ?>
                    <span class="icon fa-<?php echo $box[1]['icon']; ?>"></span>
                <?php endif; ?>

                <div class="content">

                    <?php if( $box[1]['title'] ): ?>
                    <h3><?php echo $box[1]['title']; ?></h3>
                    <?php endif; ?>

                    <?php if( $box[1]['text'] ): ?>
                    <p><?php echo $box[1]['text']; ?></p>
                    <?php endif; ?>

                </div>

            </article><!-- Front Page Box #1 End -->
            <?php endif; ?>
            
            <?php if( $box[2]['enable'] ): ?>
            <!-- Front Page Box #2 -->
            <article>

                <?php if( $box[2]['icon'] ): ?>
                    <span class="icon fa-<?php echo $box[2]['icon']; ?>"></span>
                <?php endif; ?>

                <div class="content">

                    <?php if( $box[2]['title'] ): ?>
                    <h3><?php echo $box[2]['title']; ?></h3>
                    <?php endif; ?>

                    <?php if( $box[2]['text'] ): ?>
                    <p><?php echo $box[2]['text']; ?></p>
                    <?php endif; ?>

                </div>

            </article><!-- Front Page Box #2 End -->
            <?php endif; ?>
                
            </div>
            
        </section>
        <?php endif; ?>

    <?php
    }
    
}
new Lana_Front_Page_Boxes();