<?php 

// Direct access to the file not allowed.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Lana {
	/**
	 * Lana Custom Logo
	 *
	 * @since 1.0.0
	 */
	public static function logo () {
		$custom_logo_id = esc_attr( get_theme_mod( 'custom_logo' ) );
		$logo = wp_get_attachment_image_src( $custom_logo_id, 'full' );
		if( has_custom_logo() ) {
			echo '<a href="'. esc_url( home_url( '/' ) ) .'" class="logo">';
				echo '<img src="'. esc_url( $logo[0] ) .'">';
			echo '</a>';
		} else {
			echo '<a href="'. esc_url( home_url( '/' ) ) .'" class="logo">';
				echo '<strong>'. get_bloginfo( 'name' ) .'</strong> ';
				echo get_bloginfo( 'description' );
			echo '</a>';
		}
	}
	
	/**
	 * Lana Menu
	 *
	 * @since 1.0.0
	 */
	public static function menu() {
		$args = array(
			'theme_location'	=> 'lana_nav_primary',
			'menu_class'		=> '',
			'container'			=> false,
			'walker'			=> new Lana_Nav_Walker()
		);
		echo '<nav id="menu">';
			echo '<header class="major">';
				echo '<h2>'. __( 'Menu', 'lana' ) .'</h2>';
			echo '</header>';
            if( has_nav_menu( 'lana_nav_primary' ) ) {
                echo wp_nav_menu( $args );
            } else {
                echo '<ul>';
                    echo '<li>';
                        echo '<a href="'. esc_url( home_url( '/' ) ) .'">'. __( 'Home', 'lana' ) .'</a>';
                    echo '</li>';
                echo '</ul>';
            }
		echo '</nav>';
	}
	
	/**
	 * Lana Social Icons
	 *
	 * @since 1.0.0
	 */
	public static function social_icons() {
		if( get_theme_mod( 'lana_social_icons_enable', true ) ) {
            $icons  = array(
				'Facebook'	 => esc_url( get_theme_mod( 'lana_social_facebook', '' ) ),
				'Twitter'	 => esc_url( get_theme_mod( 'lana_social_twitter', '' ) ),
				'Flickr'	 => esc_url( get_theme_mod( 'lana_social_flickr', '' ) ),
				'Vimeo'		 => esc_url( get_theme_mod( 'lana_social_vimeo', '' ) ),
				'Youtube'	 => esc_url( get_theme_mod( 'lana_social_youtube', '' ) ),
				'Instagram'	 => esc_url( get_theme_mod( 'lana_social_instagram', '' ) ),
				'Pinterest'	 => esc_url( get_theme_mod( 'lana_social_pinterest', '' ) ),
				'Tumblr'	 => esc_url( get_theme_mod( 'lana_social_tumblr', '' ) ),
				'Google'	 => esc_url( get_theme_mod( 'lana_social_google', '' ) ),
				'Dribbble'	 => esc_url( get_theme_mod( 'lana_social_dribbble', '' ) ),
				'Digg'		 => esc_url( get_theme_mod( 'lana_social_digg', '' ) ),
				'Linkedin'	 => esc_url( get_theme_mod( 'lana_social_linkedin', '' ) ),
				'Blogger'	 => esc_url( get_theme_mod( 'lana_social_blogger', '' ) ),
				'Skype'		 => esc_html( get_theme_mod( 'lana_social_skype', '' ) ),
				'Myspace'	 => esc_url( get_theme_mod( 'lana_social_myspace', '' ) ),
				'Deviantart' => esc_url( get_theme_mod( 'lana_social_deviantart', '' ) ),
				'Yahoo'		 => esc_url( get_theme_mod( 'lana_social_yahoo', '' ) ),
				'Reddit'	 => esc_url( get_theme_mod( 'lana_social_reddit', '' ) ),
				'PayPal'	 => esc_url( get_theme_mod( 'lana_social_paypal', '' ) ),
				'Dropbox'	 => esc_url( get_theme_mod( 'lana_social_dropbox', '' ) ),
				'Soundcloud' => esc_url( get_theme_mod( 'lana_social_soundcloud', '' ) ),
				'VK'		 => esc_url( get_theme_mod( 'lana_social_vk', '' ) ),
				'Email'		 => esc_html( get_theme_mod( 'lana_social_email', '' ) ),
				'RSS'		 => esc_url( get_theme_mod( 'lana_social_rss', get_bloginfo( 'rss2_url' ) ) )
			);
			echo '<ul class="icons">';
				foreach( $icons as $name => $url ) {
                    if( $name == 'Skype' && ! empty( $url ) ) {
                        $url = 'skype:' . $url .'?call';
                    }
                    if( $name == 'Email' && ! empty( $url ) ) {
                        $name = 'At';
                        $url  = 'mailto:' . $url . '?subject=Hello';
                    }
					if( ! empty( $url ) ) {
						echo '<li><a href="'. $url .'" target="_blank" class="icon fa-'. esc_attr( strtolower( $name ) ) .'">';
							echo '<span class="label">'. esc_html( $name ) .'</span>';
						echo '</a></li>';
					}
				}
			echo '</ul>';
		}
	}
    
    /**
     * Render Front Page Boxes
     *
     * @since 2.0
     */
    public static function get_front_page_boxes() {
        get_template_part( 'framework/class-lana-front-page-boxes' );
    }
    
    /**
     * Next | Previous - Post Links
     *
     * @since 2.0
     */
    public static function post_prev_next_nav() {
        if( get_previous_post_link() || get_next_post_link() ) { ?>
            <hr>
            <!-- Posts Navigation -->
            <nav class="nav-single">
                <h3 class="screen-reader-text"><?php _e( 'Post navigation', 'lana' ); ?></h3>
                <span class="nav-previous"><?php previous_post_link( '%link', '<span class="meta-nav">' . _x( '<i class="fa fa-long-arrow-left"></i>', 'Previous post link', 'lana' ) . '</span> %title' ); ?></span>
                <span class="nav-next"><?php next_post_link( '%link', '%title <span class="meta-nav">' . _x( '<i class="fa fa-long-arrow-right"></i>', 'Next post link', 'lana' ) . '</span>' ); ?></span>
            </nav><!-- Post Navigation End -->
        <?php
        }
    }
	
	/**
	 * Lana Copyright
	 *
	 * @since 1.0.0
	 */
	public static function get_copyright() {
		$copyright = get_theme_mod( 'lana_copyright', sprintf( '%s: %s', esc_attr__( 'Lana theme by', 'lana'), '<a href="'. esc_url( 'https://theme-vision.com' ).'">Theme Vision</a>' ) );
		if( $copyright ) {
			echo $copyright;
		}
	}
}

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
